@@ -29,8 +29,8 @@ void tcp_proxy_c2s_cb(struct bufferevent *bev, void *ctx);
 void tcp_proxy_s2c_cb(struct bufferevent *bev, void *ctx);
 void ftp_proxy_c2s_cb(struct bufferevent *bev, void *ctx);
 void ftp_proxy_s2c_cb(struct bufferevent *bev, void *ctx);
-struct proxy *new_proxy_buf(struct bufferevent *bev);
-void free_proxy(struct proxy *p);
+struct proxy *new_proxy_obj(struct bufferevent *bev);
+void free_proxy_obj(struct proxy *p);
 void set_ftp_data_proxy_tunnel(const char *ftp_proxy_name, 
 								struct ftp_pasv *local_fp, 
 								struct ftp_pasv *remote_fp);
